@@ -2,9 +2,8 @@
 
 # Disable the UnusedMethodArgument linter, since we need to declare the kwargs
 # in the methods, but we don't actually use them.
-# rubocop:disable Lint/UnusedMethodArgument
-
 require "grpc"
+require "singleton"
 
 module Labkit
   module Correlation
@@ -48,5 +47,3 @@ module Labkit
     end
   end
 end
-
-# rubocop:enable Lint/UnusedMethodArgument
