@@ -18,12 +18,15 @@ module Labkit
       #
       # @return [Boolean]
       def enabled?
-        # Attempt to auto-detect FIPS mode from OpenSSL
-        return true if OpenSSL.fips_mode
+        # Check if it set manually to false
+        return false if %w[0 false no].include?(ENV["FIPS_MODE"])
 
         # Otherwise allow it to be set manually via the env vars
         return true if %w[1 true yes].include?(ENV["FIPS_MODE"])
 
+        # Otherwise, attempt to auto-detect FIPS mode from OpenSSL
+        return true if OpenSSL.fips_mode
+
         false
       end
 
