@@ -1,9 +1,12 @@
 # frozen_string_literal: true
 
 require "action_dispatch"
+require "json"
 
 module Labkit
   module Middleware
+    HEADER = "X-Gitlab-Meta"
+
     # This is a rack middleware to be inserted in GitLab-rails
     # It makes sure that there's always a root context containing the correlation
     # id.
@@ -15,8 +18,12 @@ module Labkit
       end
 
       def call(env)
-        Labkit::Context.with_context(Labkit::Context::CORRELATION_ID_KEY => correlation_id(env)) do
-          @app.call(env)
+        Labkit::Context.with_context(Labkit::Context::CORRELATION_ID_KEY => correlation_id(env)) do |context|
+          status, headers, response = @app.call(env)
+
+          headers[HEADER] = context_to_json(context)
+
+          [status, headers, response]
         end
       end
 
@@ -29,6 +36,14 @@ module Labkit
       def request(env)
         ActionDispatch::Request.new(env)
       end
+
+      def context_to_json(context)
+        context
+          .to_h
+          .transform_keys { |k| k.delete_prefix("meta.") }
+          .merge("version" => "1")
+          .to_json
+      end
     end
   end
 end
