@@ -8,7 +8,9 @@ module Labkit
         # reinstantiate a context in which the job will run.
         class Server
           def call(_worker_class, job, _queue)
-            data = job.merge(Labkit::Context.log_key(:caller_id) => job["class"])
+            worker_name = (job["wrapped"].presence || job["class"]).to_s
+            data = job.merge(Labkit::Context.log_key(:caller_id) => worker_name)
+                      .select { |key, _| key.start_with?("#{Labkit::Context::LOG_KEY}.") || Labkit::Context::RAW_KEYS.include?(key.to_s) }
 
             Labkit::Context.with_context(data) do |_context|
               yield
