@@ -5,9 +5,14 @@ module Labkit
     module Rails
       module ActionView
         # For more information on the payloads: https://guides.rubyonrails.org/active_support_instrumentation.html
-        class RenderTemplateInstrumenter < AbstractInstrumenter
+        class RenderTemplateInstrumenter < Labkit::Tracing::AbstractInstrumenter
           def span_name(payload)
-            "render_template"
+            identifier = ActionView.template_identifier(payload)
+            if identifier.nil?
+              "render_template"
+            else
+              "render_template:#{identifier}"
+            end
           end
 
           def tags(payload)
