@@ -5,7 +5,7 @@ module Labkit
     module Rails
       module ActiveSupport
         # For more information on the payloads: https://guides.rubyonrails.org/active_support_instrumentation.html
-        class CacheReadInstrumenter < AbstractInstrumenter
+        class CacheReadInstrumenter < Labkit::Tracing::AbstractInstrumenter
           def span_name(payload)
             "cache_read"
           end
